from setuptools import setup, find_packages

setup(
    name='lazyfe',
    version='0.0.3',
    url='https://github.com/Diamondback-Development/lfe',
    author='WolfTheDeveloper',
    author_email='WolfTheDev@gmail.com',
    description='Official Runtime of LFE (Lazy FrontEnd)',
    packages=find_packages(),    
    install_requires=[],
)